"use strict";
/*
 * Copyright 2018-2021 Elyra Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PipelineExportDialog = void 0;
const React = __importStar(require("react"));
const PipelineService_1 = require("./PipelineService");
const KFP_FILE_TYPES = [
    { label: 'KFP domain-specific language Python code', key: 'py' },
    { label: 'KFP static configuration file (YAML formatted)', key: 'yaml' }
];
const AIRFLOW_FILE_TYPES = [
    { label: 'Airflow domain-specific language Python code', key: 'py' }
];
class PipelineExportDialog extends React.Component {
    constructor() {
        super(...arguments);
        this.state = {
            runtimePlatform: PipelineService_1.KFP_SCHEMA,
            runtimes: this.props.runtimes,
            fileTypes: KFP_FILE_TYPES
        };
        this.handleUpdate = (event) => {
            const selectedPlatform = event.target.value;
            this.updateDisplayOptions(selectedPlatform);
        };
        this.updateDisplayOptions = (platformSelection) => {
            const runtimes = PipelineService_1.PipelineService.filterRuntimes(this.props.runtimes, platformSelection);
            this.setState({
                runtimes: runtimes,
                fileTypes: platformSelection === PipelineService_1.KFP_SCHEMA ? KFP_FILE_TYPES : AIRFLOW_FILE_TYPES
            });
        };
    }
    componentDidMount() {
        this.updateDisplayOptions(this.state.runtimePlatform);
    }
    render() {
        const { fileTypes, runtimes } = this.state;
        const { schema } = this.props;
        PipelineService_1.PipelineService.sortRuntimesByDisplayName(runtimes);
        return (React.createElement("form", null,
            React.createElement("label", { htmlFor: "runtime_platform" }, "Runtime Platform:"),
            React.createElement("br", null),
            React.createElement("select", { id: "runtime_platform", name: "runtime_platform", className: "elyra-form-runtime-platform", "data-form-required": true, defaultValue: this.state.runtimePlatform, onChange: this.handleUpdate }, schema.map(schema => (React.createElement("option", { key: schema.name, value: schema.name }, schema.display_name)))),
            React.createElement("label", { htmlFor: "runtime_config" }, "Runtime Configuration:"),
            React.createElement("br", null),
            React.createElement("select", { id: "runtime_config", name: "runtime_config", className: "elyra-form-runtime-config", "data-form-required": true }, runtimes.map(runtime => (React.createElement("option", { key: runtime.name, value: runtime.name }, runtime.display_name)))),
            React.createElement("label", { htmlFor: "pipeline_filetype" }, "Export Pipeline as:"),
            React.createElement("br", null),
            React.createElement("select", { id: "pipeline_filetype", name: "pipeline_filetype", className: "elyra-form-export-filetype", "data-form-required": true }, fileTypes.map(filetype => (React.createElement("option", { key: filetype['key'], value: filetype['key'] }, filetype['label'])))),
            React.createElement("input", { type: "checkbox", className: "elyra-Dialog-checkbox", id: "overwrite", name: "overwrite" }),
            React.createElement("label", { htmlFor: "overwrite" }, "Replace if file already exists"),
            React.createElement("br", null)));
    }
}
exports.PipelineExportDialog = PipelineExportDialog;
//# sourceMappingURL=PipelineExportDialog.js.map